@@ -49,9 +49,12 @@ def parse_arguments(argsv: str = None) -> argparse.Namespace:
         dest="file",
         action="store",
         nargs="?",
-        help="With data_submission sub-command, full path to html form. "
-        "With process sub-command, override path to `.csv` file in config, "
-        "listing newly delivered sequencing data from the genome center core.",
+        help="For `data_submission` sub-command: string, path to html form. "
+        "For `process` sub-command: string, override path to `.csv` file in config, "
+        "listing newly delivered sequencing data from the genome center core. "
+        "A special case for `process` sub-command: pass `-`, and follow "
+        "the prompt on screen. For more details and examples follow the documentation "
+        "at https://tinyurl.com/y5f9pzx8 ",
     )
 
     ggroup.add_argument(
@@ -111,6 +114,24 @@ def parse_arguments(argsv: str = None) -> argparse.Namespace:
         help="Override path to AWS EC key pair file `.pem` in config.",
     )
 
+    pgroup.add_argument(
+        "-a",
+        "--ami",
+        dest="ami",
+        action="store",
+        nargs="?",
+        help="Override Amazon Machine Image (AMI) in config.",
+    )
+
+    pgroup.add_argument(
+        "-n",
+        "--instance_type",
+        dest="instance_type",
+        action="store",
+        nargs="?",
+        help="Instance Type in config for SEQC.",
+    )
+
     pgroup.add_argument(
         "-dS",
         "--dockerized-SEQC",
@@ -154,13 +175,6 @@ def parse_arguments(argsv: str = None) -> argparse.Namespace:
         "Can choose either one or both",
     )
 
-    data_submission_parser.add_argument(
-        "--project",
-        action="store_true",
-        default=False,
-        help="switch to project intake form parsing",
-    )
-
     data_submission_parser.set_defaults(func=SCRIdb.query.data_submission)
 
     process_parser = subparsers.add_parser(
@@ -183,6 +197,13 @@ def parse_arguments(argsv: str = None) -> argparse.Namespace:
         help="Skip `hashtag` run on submitted jobs.",
     )
 
+    process_parser.add_argument(
+        "--vdj",
+        action="store_false",
+        default=True,
+        help="Skip `VDJ` (TCR) run on submitted jobs.",
+    )
+
     process_parser.add_argument(
         "--atac",
         action="store_false",
@@ -388,5 +409,9 @@ def parse_arguments(argsv: str = None) -> argparse.Namespace:
     )
     args.email = config["email"] if not args.email else args.email
     args.pem = config["pem"] if not args.pem else args.pem
+    args.ami = config["ami"] if not args.ami else args.ami
+    args.instance_type = (
+        config["instance_type"] if not args.instance_type else args.instance_type
+    )
 
     return args
