@@ -520,6 +520,12 @@ def projectdata_sql(kwargs: dict) -> str:
         # iterate through common words to abbreviate
         for k, v in abbrv.items():
             projShortName = re.sub(k, v, projShortName)
+        confirm = input(
+            "Confirm project short name (yes, no): `{}`".format(projShortName)
+        )
+        if confirm.lower() not in 'yes':
+            projShortName = input("Enter project short name: ")
+
         kwargs["projShortName"] = projShortName
 
     # insert new project to database
