@@ -601,9 +601,6 @@ def prepare_statements(sample_data: pd.DataFrame) -> dict:
                     _, bucket, key, _, _ = urllib.parse.urlsplit(target_genomic)
                     cmd.append([bucket, key.strip("/"), source_genomic])
 
-        # sample_set[str(sample_.id) + "_" + sample_.label] = dict(
-        #     cmd=cmd, statement=statement
-        # )
         sample_set[str(sample_.id) + "_" + sample_.label] = dict(cmd=cmd)
 
     return sample_set
@@ -642,14 +639,14 @@ def put_object(
     target_path = os.path.join("s3://", dest_bucket_name, dest_object_name)
     cmd = f"aws s3 cp {src_data} {target_path}"
 
-    out, err = execute_cmd(cmd)
-    if err:
-        logging.error(
-            "Failed to add %s to %s!!",
-            os.path.basename(dest_object_name),
-            os.path.dirname(dest_object_name),
-        )
-        return err, False
+    # out, err = execute_cmd(cmd)
+    # if err:
+    #     logging.error(
+    #         "Failed to add %s to %s!!",
+    #         os.path.basename(dest_object_name),
+    #         os.path.dirname(dest_object_name),
+    #     )
+    #     return err, False
 
     # check for integrity
     obj = boto3.resource("s3").Object(dest_bucket_name, dest_object_name)
@@ -731,47 +728,33 @@ def copy_files_to_processing_folder(sample_data: pd.DataFrame, **kwargs) -> List
             (key.split("_")[0],),
         )
         res = db_connect.cur.fetchall()
-        if not res:
-            logging.warning(
-                "No records found for sample {}:\n\t{}".format(
-                    key.split("_")[0], db_connect.cur.statement
-                )
+        try:
+            assert res, "No records found for sample {}:\n\t{}".format(
+                key.split("_")[0], db_connect.cur.statement
             )
+            for i in zip(["IGO_sub_date", "sequencing_date"], res[0]):
+                assert isinstance(
+                    i[1], datetime.date
+                ), "Wrong date format in important dates!\n\t{}\n\t{}".format(
+                    i, db_connect.cur.statement
+                )
+        except AssertionError as e:
+            logging.warning(str(e))
             logging.warning(
                 "Sample '{}' will be excluded from processing!".format(
-                    key.split("_")[0]
+                    key.spput_objectlit("_")[0]
                 )
             )
-            failed_samples.append(str(key.split("_")[0]))
             logging.warning("Fix the missing dates and try again..")
-
+            failed_samples.append(str(key.split("_")[0]))
         else:
-            for i in zip(["IGO_sub_date", "sequencing_date"], res[0]):
-                if not isinstance(i[1], datetime.date):
-                    logging.error(
-                        "Wrong date format in important dates!\n\t{}\n\t{}".format(
-                            i, db_connect.cur.statement
-                        )
-                    )
-                    logging.warning(
-                        "Sample '{}' will be excluded from processing!".format(
-                            key.split("_")[0]
-                        )
-                    )
-                    failed_samples.append(str(key.split("_")[0]))
-                    logging.warning("Fix the missing dates and try again..")
-                else:
-                    # success_list = []
-                    for cmd in sample_set[key]["cmd"]:
-                        dest_bucket_name, dest_object_name, src_data = cmd
-                        msg, success = put_object(
-                            dest_bucket_name,
-                            dest_object_name,
-                            src_data,
-                            kwargs["md5sums"],
-                        )
-                        if not success:
-                            failed_samples.append(str(key))
+            for cmd in sample_set[key]["cmd"]:
+                dest_bucket_name, dest_object_name, src_data = cmd
+                msg, success = put_object(
+                    dest_bucket_name, dest_object_name, src_data, kwargs["md5sums"],
+                )
+                if not success:
+                    failed_samples.append(str(key))
 
     return failed_samples
 
