@@ -5,20 +5,20 @@ The final step in processing single cell sequencing data.
 The following tools are used to transfer raw data and SEQC outputs to their final
 destination, and grant access to collaborators to their data.
 """
-import re
 import os
 import random
+import re
 import string
 import urllib.parse
 from typing import Tuple
 
-import pandas as pd
 import boto3
+import pandas as pd
 import regex
 from botocore.exceptions import ClientError
 from tabulate import tabulate
 
-from .tools import execute_cmd, db_connect
+from .tools import db_connect, execute_cmd, di
 from .upload_stats import get_objects
 
 
@@ -288,7 +288,7 @@ def data_transfer(
             if target is None:
                 df["destination"] = df.PI_email.str.split("@", expand=True)[0]
                 df["destination"] = (
-                    "s3://dp-lab-data/collaborators"
+                    "s3://dp-lab-data/collaborators/"
                     + df["destination"].astype(str)
                     + "/"
                 )
@@ -399,9 +399,22 @@ def data_transfer(
     df["dest"] = dest
 
     for i in df.itertuples():
-        # TODO: update run_records with new path
-        statement = "UPDATE `raw_data` SET `s3uri`='{}' WHERE sampleData_id={}".format(
-            os.path.join(i.dest, ""), i.id
+        statement_1 = (
+            "UPDATE `raw_data` SET `s3uri`='{}' WHERE "
+            "sampleData_id={} AND `platform` = {}".format(
+                os.path.join(i.dest, ""), i.id, di[i.Run_Name]
+            )
+        )
+        statement_2 = (
+            "UPDATE `run_records` SET `analysis_storage` = '{}' "
+            "WHERE `rawData_id` IN "
+            "(SELECT MAX(`id`) FROM `raw_data` "
+            "WHERE `sampleData_id` = {} AND `platform` = {} "
+            "GROUP BY `sampleData_id`)".format(
+                os.path.join(i.dest, analysis_results_key[i.Run_Name], ""),
+                i.id,
+                di[i.Run_Name],
+            )
         )
         try:
             # update location in database
@@ -457,7 +470,7 @@ def data_transfer(
                         )
                     )
             statement2 = ""
-        statements = "; ".join([statement, statement1, statement2])
+        statements = "; ".join([statement_1, statement_2, statement1, statement2])
         for com in i.command:
             print("Executing command: {}".format(com))
             out, err = execute_cmd(com)
