@@ -203,11 +203,8 @@ def worker_main(
         "AND `platform`={} AND `IGO_id`={}"
     )
     q_records = (
-        "INSERT INTO `run_records` (`rawData_id`,`tools_id`,`state`) "
-        "VALUES (%s,%s,1)"
-    )
-    q_cromwell = (
-        "INSERT INTO `cromwell_manager` (runRecords_id,cromwell_id) VALUES (%s, %s)"
+        "INSERT INTO `run_records` (`rawData_id`,`tools_id`,`workflow_id`, `state`) "
+        "VALUES (%s,%s,%s,1)"
     )
     q_tool = "SELECT `id` FROM `tools` WHERE `tool`='{}'"
 
@@ -222,6 +219,14 @@ def worker_main(
             )
             print("Update `raw_data`:\n\t", db_connect.cur.statement)
             db_connect.db.commit()
+        # update hashtag/citeseq status
+        if row.platform in (2, 3):
+            statement = (
+                "UPDATE `hashtag_lib` SET `status`=2 WHERE "
+                "`sampleData_id`={}".format(row.id)
+            )
+            db_connect.cur.execute(statement)
+            print(db_connect.cur.statement)
 
     idx_seqc = sample_data_["run_name"].map(
         lambda x: x
@@ -266,7 +271,7 @@ def worker_main(
 
                 if rawData_id:
                     db_connect.cur.execute(
-                        q_records, (rawData_id[0], tools_id,),
+                        q_records, (rawData_id[0], tools_id, args["ami"]),
                     )
                     print("Update `run_records`:\n\t", db_connect.cur.statement)
 
@@ -303,8 +308,10 @@ def worker_main(
                 rawData_id = [i[0] for i in db_connect.cur.fetchall()]
 
                 if rawData_id:
+                    # TODO: workflow_id set for "ND" needs to be changed to a known id,
+                    #   e.g. ami-12345 or cromwel-${uuid}
                     db_connect.cur.execute(
-                        q_records, (rawData_id[0], tools_id,),
+                        q_records, (rawData_id[0], tools_id, "ND"),
                     )
                     print("Update `run_records`:\n\t", db_connect.cur.statement)
 
@@ -384,17 +391,14 @@ def worker_main(
                     db_connect.cur.execute(q_raw.format(label_id, platform, igo_id))
                     rawData_id = [i[0] for i in db_connect.cur.fetchall()]
                     db_connect.cur.execute(
-                        q_records, (rawData_id[0], tools_id,),
+                        q_records,
+                        (
+                            rawData_id[0],
+                            tools_id,
+                            "cromwell-" + str(json.loads(out["stdout"])["id"]),
+                        ),
                     )
                     print("Update `run_records`:\n\t", db_connect.cur.statement)
-                    db_connect.cur.execute("SELECT LAST_INSERT_ID()")
-                    runRecords_id = [i[0] for i in db_connect.cur.fetchall()]
-
-                    db_connect.cur.execute(
-                        q_cromwell,
-                        (runRecords_id[0], json.loads(out["stdout"])["id"],),
-                    )
-                    print("Update `cromwell_manager`:\n\t", db_connect.cur.statement)
 
                     db_connect.cur.execute(
                         "UPDATE hashtag_lib SET `status`=3 "
@@ -469,17 +473,14 @@ def worker_main(
                     db_connect.cur.execute(q_raw.format(label_id, platform, igo_id))
                     rawData_id = [i[0] for i in db_connect.cur.fetchall()]
                     db_connect.cur.execute(
-                        q_records, (rawData_id[0], tools_id,),
+                        q_records,
+                        (
+                            rawData_id[0],
+                            tools_id,
+                            "cromwell-" + str(json.loads(out["stdout"])["id"]),
+                        ),
                     )
                     print("Update `run_records`:\n\t", db_connect.cur.statement)
-                    db_connect.cur.execute("SELECT LAST_INSERT_ID()")
-                    runRecords_id = [i[0] for i in db_connect.cur.fetchall()]
-
-                    db_connect.cur.execute(
-                        q_cromwell,
-                        (runRecords_id[0], json.loads(out["stdout"])["id"],),
-                    )
-                    print("Update `cromwell_manager`:\n\t", db_connect.cur.statement)
 
                     db_connect.cur.execute(
                         "UPDATE TCR_lib SET `status`=3 "
@@ -526,8 +527,10 @@ def worker_main(
                 rawData_id = [i[0] for i in db_connect.cur.fetchall()]
 
                 if rawData_id:
+                    # TODO: workflow_id set for "ND" needs to be changed to a known id,
+                    #   e.g. ami-12345 or cromwell-${uuid}
                     db_connect.cur.execute(
-                        q_records, (rawData_id[0], tools_id,),
+                        q_records, (rawData_id[0], tools_id, "ND"),
                     )
                     print("Update `run_records`:\n\t", db_connect.cur.statement)
 
